Class: Bitfab::NoOpCurrentSpan

Inherits:
Object
  • Object
show all
Defined in:
lib/bitfab.rb

Overview

No-op span handle returned when outside a span context. All methods do nothing, preventing crashes when called outside traced code.

Instance Method Summary collapse

Instance Method Details

#add_context(_context) ⇒ Object



31
32
33
# File 'lib/bitfab.rb', line 31

def add_context(_context)
  # No-op
end

#idObject



23
24
25
# File 'lib/bitfab.rb', line 23

def id
  ""
end

#set_prompt(_prompt) ⇒ Object



35
36
37
# File 'lib/bitfab.rb', line 35

def set_prompt(_prompt)
  # No-op
end

#trace_idObject



27
28
29
# File 'lib/bitfab.rb', line 27

def trace_id
  ""
end