Class: Bitfab::NoOpCurrentTrace
- Inherits:
-
Object
- Object
- Bitfab::NoOpCurrentTrace
- Defined in:
- lib/bitfab.rb
Overview
No-op trace handle returned when outside a span context. All methods do nothing, preventing crashes when called outside traced code.
Instance Method Summary collapse
- #add_context(_context) ⇒ Object
- #set_metadata(_metadata) ⇒ Object
- #set_session_id(_session_id) ⇒ Object
Instance Method Details
#add_context(_context) ⇒ Object
45 46 47 |
# File 'lib/bitfab.rb', line 45 def add_context(_context) # No-op end |
#set_metadata(_metadata) ⇒ Object
41 42 43 |
# File 'lib/bitfab.rb', line 41 def () # No-op end |
#set_session_id(_session_id) ⇒ Object
37 38 39 |
# File 'lib/bitfab.rb', line 37 def set_session_id(_session_id) # No-op end |