Exception: Bitfab::DbBranchReplayError
- Inherits:
-
StandardError
- Object
- StandardError
- Bitfab::DbBranchReplayError
- Defined in:
- lib/bitfab/replay.rb
Overview
A requested replay database branch could not be resolved. The resolver code and original message remain structured for callers to inspect.
Instance Attribute Summary collapse
-
#code ⇒ Object
readonly
Returns the value of attribute code.
-
#original_trace_id ⇒ Object
readonly
Returns the value of attribute original_trace_id.
Instance Method Summary collapse
-
#initialize(code, message, original_trace_id) ⇒ DbBranchReplayError
constructor
A new instance of DbBranchReplayError.
Constructor Details
#initialize(code, message, original_trace_id) ⇒ DbBranchReplayError
Returns a new instance of DbBranchReplayError.
20 21 22 23 24 |
# File 'lib/bitfab/replay.rb', line 20 def initialize(code, , original_trace_id) super() @code = code @original_trace_id = original_trace_id end |
Instance Attribute Details
#code ⇒ Object (readonly)
Returns the value of attribute code.
18 19 20 |
# File 'lib/bitfab/replay.rb', line 18 def code @code end |
#original_trace_id ⇒ Object (readonly)
Returns the value of attribute original_trace_id.
18 19 20 |
# File 'lib/bitfab/replay.rb', line 18 def original_trace_id @original_trace_id end |