Class: Bitfab::NoOpCurrentSpan

Inherits:
Object
  • Object
show all
Defined in:
lib/bitfab.rb

Overview

No-op span handle returned when outside a span context. All methods do nothing, preventing crashes when called outside traced code.

Instance Method Summary collapse

Instance Method Details

#add_context(_context) ⇒ Object



30
31
32
# File 'lib/bitfab.rb', line 30

def add_context(_context)
  # No-op
end

#idObject



22
23
24
# File 'lib/bitfab.rb', line 22

def id
  ""
end

#set_prompt(_prompt) ⇒ Object



34
35
36
# File 'lib/bitfab.rb', line 34

def set_prompt(_prompt)
  # No-op
end

#trace_idObject



26
27
28
# File 'lib/bitfab.rb', line 26

def trace_id
  ""
end