Class: Bitfab::NoOpCurrentSpan

Inherits:
Object
  • Object
show all
Defined in:
lib/bitfab.rb

Overview

No-op span handle returned when outside a span context. All methods do nothing, preventing crashes when called outside traced code.

Instance Method Summary collapse

Instance Method Details

#add_context(_context) ⇒ Object



25
26
27
# File 'lib/bitfab.rb', line 25

def add_context(_context)
  # No-op
end

#set_prompt(_prompt) ⇒ Object



29
30
31
# File 'lib/bitfab.rb', line 29

def set_prompt(_prompt)
  # No-op
end

#trace_idObject



21
22
23
# File 'lib/bitfab.rb', line 21

def trace_id
  ""
end