Class: Bitfab::NoOpCurrentSpan
- Inherits:
-
Object
- Object
- Bitfab::NoOpCurrentSpan
- Defined in:
- lib/bitfab.rb
Overview
No-op span handle returned when outside a span context. All methods do nothing, preventing crashes when called outside traced code.
Instance Method Summary collapse
Instance Method Details
#add_context(_context) ⇒ Object
23 24 25 |
# File 'lib/bitfab.rb', line 23 def add_context(_context) # No-op end |
#set_prompt(_prompt) ⇒ Object
27 28 29 |
# File 'lib/bitfab.rb', line 27 def set_prompt(_prompt) # No-op end |
#trace_id ⇒ Object
19 20 21 |
# File 'lib/bitfab.rb', line 19 def trace_id "" end |