Class: Bitfab::NoOpCurrentSpan

Inherits:
Object
  • Object
show all
Defined in:
lib/bitfab.rb

Overview

No-op span handle returned when outside a span context. All methods do nothing, preventing crashes when called outside traced code.

Instance Method Summary collapse

Instance Method Details

#add_context(_context) ⇒ Object



22
23
24
# File 'lib/bitfab.rb', line 22

def add_context(_context)
  # No-op
end

#set_prompt(_prompt) ⇒ Object



26
27
28
# File 'lib/bitfab.rb', line 26

def set_prompt(_prompt)
  # No-op
end

#trace_idObject



18
19
20
# File 'lib/bitfab.rb', line 18

def trace_id
  ""
end