Class: Bitfab::NoOpCurrentSpan

Inherits:
Object
  • Object
show all
Defined in:
lib/bitfab.rb

Overview

No-op span handle returned when outside a span context. All methods do nothing, preventing crashes when called outside traced code.

Instance Method Summary collapse

Instance Method Details

#add_context(_context) ⇒ Object



20
21
22
# File 'lib/bitfab.rb', line 20

def add_context(_context)
  # No-op
end

#set_prompt(_prompt) ⇒ Object



24
25
26
# File 'lib/bitfab.rb', line 24

def set_prompt(_prompt)
  # No-op
end

#trace_idObject



16
17
18
# File 'lib/bitfab.rb', line 16

def trace_id
  ""
end