Class: Bitfab::NoOpCurrentTrace
- Inherits:
-
Object
- Object
- Bitfab::NoOpCurrentTrace
- Defined in:
- lib/bitfab.rb
Overview
No-op trace handle returned when outside a span context. All methods do nothing, preventing crashes when called outside traced code.
Instance Method Summary collapse
- #add_context(_context) ⇒ Object
- #set_metadata(_metadata) ⇒ Object
- #set_session_id(_session_id) ⇒ Object
Instance Method Details
#add_context(_context) ⇒ Object
43 44 45 |
# File 'lib/bitfab.rb', line 43 def add_context(_context) # No-op end |
#set_metadata(_metadata) ⇒ Object
39 40 41 |
# File 'lib/bitfab.rb', line 39 def () # No-op end |
#set_session_id(_session_id) ⇒ Object
35 36 37 |
# File 'lib/bitfab.rb', line 35 def set_session_id(_session_id) # No-op end |