Class: Bitfab::NoOpCurrentTrace
- Inherits:
-
Object
- Object
- Bitfab::NoOpCurrentTrace
- Defined in:
- lib/bitfab.rb
Overview
No-op trace handle returned when outside a span context. All methods do nothing, preventing crashes when called outside traced code.
Instance Method Summary collapse
- #add_context(_context) ⇒ Object
- #set_metadata(_metadata) ⇒ Object
- #set_session_id(_session_id) ⇒ Object
Instance Method Details
#add_context(_context) ⇒ Object
42 43 44 |
# File 'lib/bitfab.rb', line 42 def add_context(_context) # No-op end |
#set_metadata(_metadata) ⇒ Object
38 39 40 |
# File 'lib/bitfab.rb', line 38 def () # No-op end |
#set_session_id(_session_id) ⇒ Object
34 35 36 |
# File 'lib/bitfab.rb', line 34 def set_session_id(_session_id) # No-op end |