Class: Bitfab::NoOpCurrentTrace
- Inherits:
-
Object
- Object
- Bitfab::NoOpCurrentTrace
- Defined in:
- lib/bitfab.rb
Overview
No-op trace handle returned when outside a span context. All methods do nothing, preventing crashes when called outside traced code.
Instance Method Summary collapse
- #add_context(_context) ⇒ Object
- #set_metadata(_metadata) ⇒ Object
- #set_session_id(_session_id) ⇒ Object
Instance Method Details
#add_context(_context) ⇒ Object
40 41 42 |
# File 'lib/bitfab.rb', line 40 def add_context(_context) # No-op end |
#set_metadata(_metadata) ⇒ Object
36 37 38 |
# File 'lib/bitfab.rb', line 36 def () # No-op end |
#set_session_id(_session_id) ⇒ Object
32 33 34 |
# File 'lib/bitfab.rb', line 32 def set_session_id(_session_id) # No-op end |